@@ -6,10 +6,10 @@ from fastapi.responses import JSONResponse
 
 
 class MagicException(Exception):
-    def __init__(self, message: str):
-        # self.status_code: int = 452
-        self.status_code: int = 418
+    def __init__(self, message: str, json_response: dict = None):
+        self.status_code: int = 452
         self.message: str = message
+        self.json_response: dict = json_response or {}
 
 
 class BackendException(MagicException):
@@ -32,5 +32,9 @@ class TwilioException(MagicException):
 def backend_exception_handler(request: Request, exc: MagicException):
     return JSONResponse(
         status_code=exc.status_code,
-        content={"success": False, "message": f"{exc.message}"},
+        content={
+            "success": False,
+            "message": f"{exc.message}",
+            "json_response": exc.json_response,
+        },
     )
