@@ -1,11 +1,14 @@
 import boto3
 
 from magicdb.Models import DateModel, MagicModel
-from magicapi import settings
+# from magicapi import settings
+# from magicapi.Globals.G import g
 
 
+from magicapi import g
+
 dynamodb = boto3.resource("dynamodb")
-table = dynamodb.Table(settings.tasks_table_name)
+table = dynamodb.Table(g.settings.tasks_table_name)
 
 
 class TaskParams(MagicModel):
@@ -29,3 +32,4 @@ class Task(DateModel):
     @staticmethod
     def get_table():
         return table
+
